@@ -7,6 +7,7 @@ import sys
 from contextlib import contextmanager
 from functools import partial
 from pathlib import Path
+from typing import ClassVar
 
 import pytest
 
@@ -24,7 +25,7 @@ def pytest_configure(config):
     """Ensure randomly is called before we re-order"""
     manager = config.pluginmanager
 
-    order = manager.hook.pytest_collection_modifyitems._nonwrappers  # noqa: SLF001
+    order = manager.hook.pytest_collection_modifyitems.get_hookimpls()
     dest = next((i for i, p in enumerate(order) if p.plugin is manager.getplugin("randomly")), None)
     if dest is not None:
         from_pos = next(i for i, p in enumerate(order) if p.plugin is manager.getplugin(__file__))
@@ -57,7 +58,7 @@ def link_folder(has_symlink_support):
         return os.symlink
     if sys.platform == "win32":
         # on Windows junctions may be used instead
-        import _winapi
+        import _winapi  # noqa: PLC0415
 
         return getattr(_winapi, "CreateJunction", None)
     return None
@@ -125,7 +126,7 @@ def _ensure_py_info_cache_empty(session_app_data):
 @contextmanager
 def change_os_environ(key, value):
     env_var = key
-    previous = os.environ[env_var] if env_var in os.environ else None
+    previous = os.environ.get(env_var, None)
     os.environ[env_var] = value
     try:
         yield
@@ -196,7 +197,7 @@ def coverage_env(monkeypatch, link, request):
     """
     if COVERAGE_RUN and "_no_coverage" not in request.fixturenames:
         # we inject right after creation, we cannot collect coverage on site.py - used for helper scripts, such as debug
-        from virtualenv import run
+        from virtualenv import run  # noqa: PLC0415
 
         def _session_via_cli(args, options, setup_logging, env=None):
             session = prev_run(args, options, setup_logging, env)
@@ -205,7 +206,7 @@ def coverage_env(monkeypatch, link, request):
             def create_run():
                 result = old_run()
                 obj["cov"] = EnableCoverage(link)
-                obj["cov"].__enter__(session.creator)
+                obj["cov"].__enter__(session.creator)  # noqa: PLC2801
                 return result
 
             monkeypatch.setattr(session.creator, "run", create_run)
@@ -242,8 +243,10 @@ if COVERAGE_RUN:
     import coverage
 
     class EnableCoverage:
-        _COV_FILE = Path(coverage.__file__)
-        _ROOT_COV_FILES_AND_FOLDERS = [i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")]
+        _COV_FILE: ClassVar[Path] = Path(coverage.__file__)
+        _ROOT_COV_FILES_AND_FOLDERS: ClassVar[list[Path]] = [
+            i for i in _COV_FILE.parents[1].iterdir() if i.name.startswith("coverage")
+        ]
 
         def __init__(self, link) -> None:
             self.link = link
@@ -282,7 +285,7 @@ def special_char_name():
             trip = char.encode(encoding, errors="strict").decode(encoding)
             if char == trip:
                 result += char
-        except ValueError:
+        except ValueError:  # noqa: PERF203
             continue
     assert result
     return result
@@ -348,7 +351,7 @@ def _skip_if_test_in_system(session_app_data):
         pytest.skip("test not valid if run under system")
 
 
-if IS_PYPY:
+if IS_PYPY or (IS_WIN and sys.version_info[0:2] >= (3, 13)):  # https://github.com/adamchainz/time-machine/issues/456
 
     @pytest.fixture()
     def time_freeze(freezer):
